@@ -3,6 +3,7 @@ package Devel::Size;
 use strict;
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $warn);
 
+require 5.006;
 require Exporter;
 require DynaLoader;
 
@@ -16,7 +17,7 @@ require DynaLoader;
 @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 @EXPORT = qw( );
-$VERSION = '0.68';
+$VERSION = '0.70';
 
 bootstrap Devel::Size $VERSION;
 
@@ -25,6 +26,8 @@ $warn = 1;
 1;
 __END__
 
+=pod
+
 =head1 NAME
 
 Devel::Size - Perl extension for finding the memory usage of Perl variables
@@ -41,14 +44,16 @@ Devel::Size - Perl extension for finding the memory usage of Perl variables
   my $foo = {a => [1, 2, 3],
 	  b => {a => [1, 3, 4]}
          };
-  my  $total_size = total_size($foo);
+  my $total_size = total_size($foo);
 
 =head1 DESCRIPTION
 
-This module figures out the real sizes of Perl variables in bytes.  
+This module figures out the real size of Perl variables in bytes, as
+accurately as possible.
+
 Call functions with a reference to the variable you want the size
 of.  If the variable is a plain scalar it returns the size of
-the scalar.  If the variable is a hash or an array, use a reference
+this scalar.  If the variable is a hash or an array, use a reference
 when calling.
 
 =head1 FUNCTIONS
@@ -241,10 +246,10 @@ Maintained now by Tels <http://bloodgate.com>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005 Dan Sugalski, Copyright (C) 2007 Tels
+Copyright (C) 2005 Dan Sugalski, Copyright (C) 2007-2008 Tels
 
 This module is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+under the same terms as Perl v5.8.8.
 
 =head1 SEE ALSO
 
